==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/Util__244.h <==
// final class org.dellroad.jc.cgen.Util$4

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 40fb19bcaef0e969 org_dellroad_jc_cgen_Util__244

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_Util__244_H_
#define _JC_org_dellroad_jc_cgen_Util__244_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_dellroad_jc_cgen_Util__244$object;
struct _jc_org_dellroad_jc_cgen_Util__24OrderTypeSwitch$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_Util__244$sub_refs	_jc_org_dellroad_jc_cgen_Util__244$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244$sub_nonrefs	_jc_org_dellroad_jc_cgen_Util__244$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244$refs	_jc_org_dellroad_jc_cgen_Util__244$refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244$nonrefs	_jc_org_dellroad_jc_cgen_Util__244$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244$object	_jc_org_dellroad_jc_cgen_Util__244$object;

typedef const struct _jc_org_dellroad_jc_cgen_Util__244$vmethods	_jc_org_dellroad_jc_cgen_Util__244$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_Util__244$vtable	_jc_org_dellroad_jc_cgen_Util__244$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_Util__244$vtype	_jc_org_dellroad_jc_cgen_Util__244$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_Util__244$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *);

// Virtual methods
extern jint _jc_org_dellroad_jc_cgen_Util__244$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_org_dellroad_jc_cgen_Util__244$method$getOrder$bc6bf15dbc68e576(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *, struct _jc_soot_Type$object *);
extern void _jc_org_dellroad_jc_cgen_Util__244$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_Util__244$method_info$compare$ef65339aa5f9531b;
extern _jc_method _jc_org_dellroad_jc_cgen_Util__244$method_info$getOrder$bc6bf15dbc68e576;
extern _jc_method _jc_org_dellroad_jc_cgen_Util__244$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern jint _jc_org_dellroad_jc_cgen_Util__244$method$access__240$2b18c097ed69fb05(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *);
extern void _jc_org_dellroad_jc_cgen_Util__244$method$access__241$f68b33965efe8856(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *, jint);

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_Util__244$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	jint	(*getOrder$bc6bf15dbc68e576)(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *, struct _jc_soot_Type$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_Util__244$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_Util__244$vmethods	org_dellroad_jc_cgen_Util__244;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_Util__244$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_Util__244$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__244$sub_refs {
	struct _jc_org_dellroad_jc_cgen_Util__24OrderTypeSwitch$object	*ots;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__244$refs {
    _jc_org_dellroad_jc_cgen_Util__244$sub_refs	org_dellroad_jc_cgen_Util__244;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__244$sub_nonrefs {
	jint	ots__5forder;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__244$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_Util__244$sub_nonrefs	org_dellroad_jc_cgen_Util__244;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_Util__244$object {
	_jc_org_dellroad_jc_cgen_Util__244$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_Util__244$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_Util__244$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_Util__244$vtype _jc_org_dellroad_jc_cgen_Util__244$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_Util__244, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_Util__244$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_Util__244_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/Util__244.h <==
// final class org.dellroad.jc.cgen.Util$4

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 40fb19bcaef0e969 org_dellroad_jc_cgen_Util__244

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_Util__244_H_
#define _JC_org_dellroad_jc_cgen_Util__244_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_dellroad_jc_cgen_Util__244$object;
struct _jc_org_dellroad_jc_cgen_Util__24OrderTypeSwitch$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_Util__244$sub_refs	_jc_org_dellroad_jc_cgen_Util__244$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244$sub_nonrefs	_jc_org_dellroad_jc_cgen_Util__244$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244$refs	_jc_org_dellroad_jc_cgen_Util__244$refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244$nonrefs	_jc_org_dellroad_jc_cgen_Util__244$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__244$object	_jc_org_dellroad_jc_cgen_Util__244$object;

typedef const struct _jc_org_dellroad_jc_cgen_Util__244$vmethods	_jc_org_dellroad_jc_cgen_Util__244$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_Util__244$vtable	_jc_org_dellroad_jc_cgen_Util__244$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_Util__244$vtype	_jc_org_dellroad_jc_cgen_Util__244$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_Util__244$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_org_dellroad_jc_cgen_Util__244$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_org_dellroad_jc_cgen_Util__244$method$getOrder$bc6bf15dbc68e576(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_Util__244$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_Util__244$method_info$compare$ef65339aa5f9531b;
extern _jc_method _jc_org_dellroad_jc_cgen_Util__244$method_info$getOrder$bc6bf15dbc68e576;
extern _jc_method _jc_org_dellroad_jc_cgen_Util__244$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern jint _jc_org_dellroad_jc_cgen_Util__244$method$access__240$2b18c097ed69fb05(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_Util__244$method$access__241$f68b33965efe8856(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_Util__244$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*getOrder$bc6bf15dbc68e576)(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__244$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_Util__244$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_Util__244$vmethods	org_dellroad_jc_cgen_Util__244;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_Util__244$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_Util__244$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__244$sub_refs {
	struct _jc_org_dellroad_jc_cgen_Util__24OrderTypeSwitch$object	*ots;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__244$refs {
    _jc_org_dellroad_jc_cgen_Util__244$sub_refs	org_dellroad_jc_cgen_Util__244;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__244$sub_nonrefs {
	jint	ots__5forder;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__244$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_Util__244$sub_nonrefs	org_dellroad_jc_cgen_Util__244;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_Util__244$object {
	_jc_org_dellroad_jc_cgen_Util__244$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_Util__244$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_Util__244$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_Util__244$vtype _jc_org_dellroad_jc_cgen_Util__244$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_Util__244, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_Util__244$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_Util__244_H_ */
